@@ -20,6 +20,7 @@ package org.apache.catalina;
 
 
 import java.net.URL;
+import java.util.Locale;
 import java.util.Set;
 
 import javax.servlet.ServletContainerInitializer;
@@ -58,7 +59,7 @@ import org.apache.tomcat.util.http.mapper.Mapper;
  * <p>
  *
  * @author Craig R. McClanahan
- * @version $Id: Context.java 1200158 2011-11-10 05:32:22Z kkolinko $
+ * @version $Id: Context.java 1350247 2012-06-14 14:04:20Z markt $
  */
 
 public interface Context extends Container {
@@ -69,7 +70,9 @@ public interface Context extends Container {
 
     /**
      * The LifecycleEvent type sent when a context is reloaded.
+     * @deprecated Will be removed in Tomcat 8.0.x onwards.
      */
+    @Deprecated
     public static final String RELOAD_EVENT = "reload";
 
     /**
@@ -167,7 +170,9 @@ public interface Context extends Container {
 
     /**
      * Return the Locale to character set mapper for this Context.
+     * @deprecated Use {@link #getCharset(Locale)}
      */
+    @Deprecated
     public CharsetMapper getCharsetMapper();
 
 
@@ -175,10 +180,21 @@ public interface Context extends Container {
      * Set the Locale to character set mapper for this Context.
      *
      * @param mapper The new mapper
+     *
+     * @deprecated
      */
+    @Deprecated
     public void setCharsetMapper(CharsetMapper mapper);
 
 
+    /**
+     * Obtain the character set name to use with the given Locale. Note that
+     * different Contexts may have different mappings of Locale to character
+     * set.
+     */
+    public String getCharset(Locale locale);
+
+
     /**
      * Return the URL of the XML descriptor for this context.
      */
@@ -1399,7 +1415,7 @@ public interface Context extends Container {
     public void setSendRedirectBody(boolean enable);
 
     /**
-     * Dtermines if the context is configured to included a response body as
+     * Determines if the context is configured to include a response body as
      * part of a redirect response.
      */
     public boolean getSendRedirectBody();
