@@ -31,10 +31,10 @@ import org.apache.catalina.connector.Connector;
  * and classes on the system class path.
  *
  * @author Craig R. McClanahan
- * @version $Id: Service.java 939350 2010-04-29 15:36:29Z kkolinko $
+ * @version $Id: Service.java 1200162 2011-11-10 05:37:57Z kkolinko $
  */
 
-public interface Service {
+public interface Service extends Lifecycle {
 
     // ------------------------------------------------------------- Properties
 
@@ -84,6 +84,20 @@ public interface Service {
      */
     public void setServer(Server server);
 
+    /**
+     * Return the parent class loader for this component. If not set, return
+     * {@link #getServer()} {@link Server#getParentClassLoader()}. If no server
+     * has been set, return the system class loader.
+     */
+    public ClassLoader getParentClassLoader();
+
+    /**
+     * Set the parent class loader for this service.
+     *
+     * @param parent The new parent class loader
+     */
+    public void setParentClassLoader(ClassLoader parent);
+
     // --------------------------------------------------------- Public Methods
 
 
@@ -109,14 +123,6 @@ public interface Service {
      */
     public void removeConnector(Connector connector);
 
-    /**
-     * Invoke a pre-startup initialization. This is used to allow connectors
-     * to bind to restricted ports under Unix operating environments.
-     *
-     * @exception LifecycleException If this server was already initialized.
-     */
-    public void initialize() throws LifecycleException;
-
     /**
      * Adds a named executor to the service
      * @param ex Executor
@@ -135,7 +141,7 @@ public interface Service {
      * @return Executor
      */
     public Executor getExecutor(String name);
-    
+
     /**
      * Removes an executor from the service
      * @param ex Executor
