@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.catalina.filters;
 
 import java.io.IOException;
+import java.io.Serializable;
 import java.security.SecureRandom;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
@@ -128,7 +128,7 @@ public class CsrfPreventionFilter extends FilterBase {
         }
     }
 
-
+    @Override
     public void doFilter(ServletRequest request, ServletResponse response,
             FilterChain chain) throws IOException, ServletException {
 
@@ -210,14 +210,16 @@ public class CsrfPreventionFilter extends FilterBase {
         for (int j = 0; j < random.length; j++) {
             byte b1 = (byte) ((random[j] & 0xf0) >> 4);
             byte b2 = (byte) (random[j] & 0x0f);
-            if (b1 < 10)
+            if (b1 < 10) {
                 buffer.append((char) ('0' + b1));
-            else
+            } else {
                 buffer.append((char) ('A' + (b1 - 10)));
-            if (b2 < 10)
+            }
+            if (b2 < 10) {
                 buffer.append((char) ('0' + b2));
-            else
+            } else {
                 buffer.append((char) ('A' + (b2 - 10)));
+            }
         }
 
         return buffer.toString();
@@ -226,7 +228,7 @@ public class CsrfPreventionFilter extends FilterBase {
     protected static class CsrfResponseWrapper
             extends HttpServletResponseWrapper {
 
-        private String nonce;
+        private final String nonce;
 
         public CsrfResponseWrapper(HttpServletResponse response, String nonce) {
             super(response);
@@ -263,8 +265,9 @@ public class CsrfPreventionFilter extends FilterBase {
          */
         private String addNonce(String url) {
 
-            if ((url == null) || (nonce == null))
+            if ((url == null) || (nonce == null)) {
                 return (url);
+            }
 
             String path = url;
             String query = "";
@@ -294,7 +297,9 @@ public class CsrfPreventionFilter extends FilterBase {
         }
     }
     
-    private static class LruCache<T> {
+    protected static class LruCache<T> implements Serializable {
+
+        private static final long serialVersionUID = 1L;
 
         // Although the internal implementation uses a Map, this cache
         // implementation is only concerned with the keys.
