@@ -401,9 +401,12 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
         if ( entry == null ) return;
         if ( !entry.isSerializable() ) return;
         if (entry.isPrimary() && entry.getBackupNodes()!= null && entry.getBackupNodes().length > 0) {
-            Object value = entry.getValue();
-            //check to see if we need to replicate this object isDirty()||complete
-            boolean repl = complete || ( (value instanceof ReplicatedMapEntry) && ( (ReplicatedMapEntry) value).isDirty());
+            //check to see if we need to replicate this object isDirty()||complete || isAccessReplicate()
+            ReplicatedMapEntry rentry = null;
+            if (entry.getValue() instanceof ReplicatedMapEntry) rentry = (ReplicatedMapEntry)entry.getValue();
+            boolean isDirty = rentry != null && rentry.isDirty();
+            boolean isAccess = rentry != null && rentry.isAccessReplicate();
+            boolean repl = complete || isDirty || isAccess;
             
             if (!repl) {
                 if ( log.isTraceEnabled() )
@@ -412,10 +415,9 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
                 return;
             }
             //check to see if the message is diffable
-            boolean diff = ( (value instanceof ReplicatedMapEntry) && ( (ReplicatedMapEntry) value).isDiffable());
+            boolean diff = rentry != null && rentry.isDiffable();
             MapMessage msg = null;
-            if (diff) {
-                ReplicatedMapEntry rentry = (ReplicatedMapEntry)entry.getValue();
+            if (diff && (isDirty || complete)) {
                 try {
                     rentry.lock();
                     //construct a diff message
@@ -432,16 +434,22 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
                 }
                 
             }
-            if (msg == null) {
+            if (msg == null && complete) {
                 //construct a complete
                 msg = new MapMessage(mapContextName, MapMessage.MSG_BACKUP,
                                      false, (Serializable) entry.getKey(),
                                      (Serializable) entry.getValue(),
                                      null, entry.getPrimary(),entry.getBackupNodes());
-
+            }
+            if (msg == null) {
+                //construct a access message
+                msg = new MapMessage(mapContextName, MapMessage.MSG_ACCESS,
+                        false, (Serializable) entry.getKey(), null, null, entry.getPrimary(),
+                        entry.getBackupNodes());
             }
             try {
                 if ( channel!=null && entry.getBackupNodes()!= null && entry.getBackupNodes().length > 0 ) {
+                    if (rentry != null) rentry.setLastTimeReplicated(System.currentTimeMillis());
                     channel.send(entry.getBackupNodes(), msg, channelSendOptions);
                 }
             } catch (ChannelException x) {
@@ -670,6 +678,17 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
             } //end if
             super.put(entry.getKey(), entry);
         } //end if
+
+        if (mapmsg.getMsgType() == MapMessage.MSG_ACCESS) {
+            MapEntry entry = (MapEntry)super.get(mapmsg.getKey());
+            if (entry != null) {
+                entry.setBackupNodes(mapmsg.getBackupNodes());
+                entry.setPrimary(mapmsg.getPrimary());
+                if (entry.getValue() instanceof ReplicatedMapEntry) {
+                    ((ReplicatedMapEntry) entry.getValue()).accessEntry();
+                }
+            }
+        }
     }
 
     @Override
@@ -1277,6 +1296,7 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
         public static final int MSG_INIT = 8;
         public static final int MSG_COPY = 9;
         public static final int MSG_STATE_COPY = 10;
+        public static final int MSG_ACCESS = 11;
 
         private byte[] mapId;
         private int msgtype;
@@ -1314,10 +1334,15 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
                 case MSG_INIT: return "MSG_INIT";
                 case MSG_STATE_COPY: return "MSG_STATE_COPY";
                 case MSG_COPY: return "MSG_COPY";
+                case MSG_ACCESS: return "MSG_ACCESS";
                 default : return "UNKNOWN";
             }
         }
 
+        /**
+         * @deprecated  Unused - will be removed in Tomcat 8.0.x
+         */
+        @Deprecated
         public MapMessage() {}
 
         public MapMessage(byte[] mapId,int msgtype, boolean diff,
@@ -1427,7 +1452,11 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
                 throw new RuntimeException(x);
             }
         }
-        
+
+        /**
+         * @deprecated  Unused - will be removed in 8.0.x
+         */
+        @Deprecated
         protected Member[] readMembers(ObjectInput in) throws IOException, ClassNotFoundException {
             int nodecount = in.readInt();
             Member[] members = new Member[nodecount];
@@ -1439,6 +1468,10 @@ public abstract class AbstractReplicatedMap extends ConcurrentHashMap implements
             return members;
         }
         
+        /**
+         * @deprecated  Unused - will be removed in 8.0.x
+         */
+        @Deprecated
         protected void writeMembers(ObjectOutput out,Member[] members) throws IOException {
             if ( members == null ) members = new Member[0];
             out.writeInt(members.length);
